@@ -265,20 +265,21 @@ def validation(file: str | None = None) -> str | bytes:
     isValidation = 'validation' == requestPathParts[-1] or 'validation' == requestPathParts[-2]
     view = request.query.view
     viewArcrole = request.query.viewArcrole
+    sourceZipStreamFileName = None
+    sourceZipStream = None
     if request.method == 'POST':
         mimeType = request.get_header("Content-Type")
         if mimeType and mimeType.startswith("multipart/form-data"):
-            _upload = request.files.get("upload")
-            if not _upload or not _upload.filename.endswith(".zip"):
-                errors.append(_("POST file upload must be a zip file"))
-                sourceZipStream = None
+            if upload := request.files.get("upload"):
+                sourceZipStreamFileName = upload.filename
+                sourceZipStream = upload.file
             else:
-                sourceZipStream = _upload.file
-        elif mimeType not in ('application/zip', 'application/x-zip', 'application/x-zip-compressed', 'multipart/x-zip'):
-            errors.append(_("POST must provide a zip file, Content-Type '{0}' not recognized as a zip file.").format(mimeType))
-        sourceZipStream = request.body
-    else:
-        sourceZipStream = None
+                errors.append(_("POST 'multipart/form-data' request must include 'upload' part containing the XBRL file to process."))
+        elif mimeType in ('application/zip', 'application/x-zip', 'application/x-zip-compressed', 'multipart/x-zip'):
+            sourceZipStreamFileName = request.get_header("X-File-Name")
+            sourceZipStream = request.body
+        else:
+            errors.append(_("POST request must provide an XBRL zip file to process. Content-Type '{0}' not recognized as a zip file.").format(mimeType))
     if not view and not viewArcrole:
         if requestPathParts[-1] in supportedViews:
             view = requestPathParts[-1]
@@ -350,13 +351,14 @@ def validation(file: str | None = None) -> str | bytes:
         viewFile = FileNamedStringIO(media)
         options.viewArcrole = viewArcrole
         options.viewFile = viewFile
-    return runOptionsAndGetResult(options, media, viewFile, sourceZipStream)
+    return runOptionsAndGetResult(options, media, viewFile, sourceZipStream, sourceZipStreamFileName)
 
 def runOptionsAndGetResult(
         options: RuntimeOptions,
         media: str,
         viewFile: FileNamedStringIO | None,
         sourceZipStream: FileNamedStringIO | None = None,
+        sourceZipStreamFileName: str | None = None,
         ) -> str | bytes:
     """Execute request according to options, for result in media, with *post*ed file in sourceZipStream, if any.
 
@@ -381,7 +383,7 @@ def runOptionsAndGetResult(
     else:
         responseZipStream = None
     cntlr = getCntlr()
-    successful = cntlr.run(options, sourceZipStream, responseZipStream)
+    successful = cntlr.run(options, sourceZipStream, responseZipStream, sourceZipStreamFileName)
     if media == "xml":
         response.content_type = 'text/xml; charset=UTF-8'
     elif media == "csv":
