@@ -25,7 +25,6 @@ try:
     import syslog
 except ImportError:
     syslog = None
-import tkinter.tix
 import tkinter.filedialog
 import tkinter.messagebox, traceback
 import tkinter.simpledialog
@@ -306,7 +305,6 @@ class CntlrWinMain (Cntlr.Cntlr):
         self.statusbarTimerId  = self.statusbar.after(5000, self.uiClearStatusTimerEvent)
         self.statusbar.grid(row=2, column=0, columnspan=2, sticky=EW)
 
-        #self.balloon = tkinter.tix.Balloon(windowFrame, statusbar=self.statusbar)
         self.toolbar_images = []
         toolbar = Frame(windowFrame)
         menubarColumn = 0
@@ -823,6 +821,7 @@ class CntlrWinMain (Cntlr.Cntlr):
             return
         url = DialogURL.askURL(self.parent, buttonSEC=True, buttonRSS=True)
         if url:
+            url = PackageManager.mappedUrl(url)
             self.updateFileHistory(url, False)
             for xbrlLoadedMethod in pluginClassMethods("CntlrWinMain.Xbrl.Open"):
                 url = xbrlLoadedMethod(self, url) # runs in GUI thread, allows mapping url, mult return url
@@ -841,6 +840,7 @@ class CntlrWinMain (Cntlr.Cntlr):
             return False
         url = DialogURL.askURL(self.parent, buttonSEC=False, buttonRSS=False)
         if url:
+            url = PackageManager.mappedUrl(url)
             self.fileOpenFile(url, importToDTS=True)
 
 
@@ -907,9 +907,12 @@ class CntlrWinMain (Cntlr.Cntlr):
             for modelXbrl in loadedModels:
                 self.uiThreadQueue.put((self.showLoadedXbrl, [modelXbrl, importToDTS, selectTopView]))
         else:
-            self.addToLog(format_string(self.modelManager.locale,
-                                        _("not successfully %s in %.2f secs"),
-                                        (action, time.time() - startedAt)))
+            self.addToLog(
+                format_string(self.modelManager.locale, _("No XBRL entry points could be %s from provided file in %.2f seconds"),
+                (action, time.time() - startedAt)),
+                messageCode="error",
+                level=logging.ERROR,
+            )
             self.showStatus(_("Loading terminated"), 15000)
 
     def showLoadedXbrl(self, modelXbrl, attach, selectTopView=False, isSupplementalModelXbrl=False):
