@@ -13,7 +13,7 @@ import struct
 import tarfile
 import zipfile
 import zlib
-from typing import IO, TYPE_CHECKING, Any, cast
+from typing import IO, TYPE_CHECKING, Any, TextIO, cast
 
 import regex as re
 from lxml import etree
@@ -36,7 +36,6 @@ archivePathSeparators = (".zip" + os.sep, ".xbr" + os.sep, ".xbri" + os.sep, ".t
 
 archiveFilenameSuffixes = {".zip", ".xbr", ".xbri", ".tar.gz", ".eis", ".xml", ".xfd", ".frm"}
 
-POST_UPLOADED_ZIP = os.sep + "POSTupload.zip"
 SERVER_WEB_CACHE = os.sep + "_HTTP_CACHE"
 
 TAXONOMY_PACKAGE_FILE_NAMES = ('.taxonomyPackage.xml', 'catalog.xml') # pre-PWD packages
@@ -49,9 +48,11 @@ def openFileSource(
     reloadCache: bool = False,
     base: str | None = None,
     sourceFileSource: FileSource | None = None,
+    sourceZipStreamFileName: str | None = None,
 ) -> FileSource:
     if sourceZipStream:
-        filesource = FileSource(POST_UPLOADED_ZIP, cntlr)
+        sourceZipStreamFileName = os.sep + (sourceZipStreamFileName or "POSTupload.zip")
+        filesource = FileSource(sourceZipStreamFileName, cntlr)
         filesource.openZipStream(sourceZipStream)
         if filename:
             filesource.select(filename)
@@ -167,10 +168,11 @@ class FileSource:
         self.url = str(url)  # allow either string or FileNamedStringIO
         self.baseIsHttp = isHttpUrl(self.url)
         self.cntlr = cntlr
-        self.type = self.url.lower()[-7:]
-        self.isTarGz = self.type == ".tar.gz"
-        if not self.isTarGz:
-            self.type = self.type[3:]
+        self.isTarGz = self.url.lower().endswith(".tar.gz")
+        if self.isTarGz:
+            self.type = ".tar.gz"
+        else:
+            self.type = os.path.splitext(self.url.lower())[1]
         self.isZip = self.type == ".zip" or isReportPackageExtension(self.url)
         self.isZipBackslashed = False # windows style backslashed paths
         self.isEis = self.type == ".eis"
@@ -192,11 +194,14 @@ class FileSource:
                 if basefile:
                     with openFileStream(self.cntlr, basefile, 'rb') as fileStream:
                         self.isZip = zipfile.is_zipfile(fileStream)
+            except OSError:
+                # Can't load self.url content. It's not a zip file.
+                # We don't use os.path.isfile because self.url may be an embeded zip file.
+                pass
             except Exception as err:
-                # Log the error, but don't record a validation error.
+                # Log the error at info level (which is sent to the GUI log), but don't record a validation error.
                 # Validation is deferred to the validation classes. Filesource is unaware of the specific errors that should be raised.
                 self.logError(err)
-                pass
 
 
         # for SEC xml files, check if it's an EIS anyway
@@ -516,11 +521,7 @@ class FileSource:
         binary: bool = False,
         stripDeclaration: bool = False,
         encoding: str | None = None,
-    ) -> (
-            tuple[io.BytesIO | IO[Any]]
-            | tuple[FileNamedTextIOWrapper, str | None]
-            | tuple[io.TextIOWrapper, str | None]
-        ):
+    ) -> tuple[io.BytesIO | IO[Any]] | tuple[TextIO, str | None]:
         '''
             for text, return a tuple of (open file handle, encoding)
             for binary, return a tuple of (open file handle, )
@@ -802,8 +803,7 @@ def openFileStream(
     if PackageManager.isMappedUrl(filepath):  # type: ignore[no-untyped-call]
         filepath = PackageManager.mappedUrl(filepath)  # type: ignore[no-untyped-call]
     elif (
-            isHttpUrl(filepath)
-            and cntlr
+            cntlr
             and hasattr(cntlr, "modelManager")
         ): # may be called early in initialization for PluginManager
         filepath = cntlr.modelManager.disclosureSystem.mappedUrl(filepath)  # type: ignore[no-untyped-call]
@@ -848,7 +848,7 @@ def openFileStream(
 
 def openXmlFileStream(
     cntlr: Cntlr | None, filepath: str, stripDeclaration: bool = False
-) -> tuple[io.TextIOWrapper, str]:
+) -> tuple[TextIO, str]:
     # returns tuple: (fileStream, encoding)
     openedFileStream = openFileStream(cntlr, filepath, 'rb')
 
