@@ -22,7 +22,7 @@ objects to interface to SQL-obtained data.
 
 ModelType represents an anonymous or explicit element type.  It includes methods that determine
 the base XBRL type (such as monetaryItemType), the base XML type (such as decimal), substitution
-group chains, facits, and attributes.
+group chains, facets, and attributes.
 
 ModelAttributeGroup and ModelAttribute provide sufficient mechanism to identify element attributes,
 their types, and their default or fixed values.
@@ -1408,7 +1408,7 @@ class ModelType(ModelNamableTerm):
                 ("QName", self.qname),
                 ("xsd type", self.baseXsdType),
                 ("derived from", self.qnameDerivedFrom),
-                ("facits", self.facets))
+                ("facets", self.facets))
 
     def __repr__(self):
         return ("modelType[{0}, qname: {1}, derivedFrom: {2}, {3}, line {4}]"
