@@ -143,6 +143,10 @@ class Validate:
         self.modelXbrl.info("info", "RSS Feed", modelDocument=self.modelXbrl)
         from arelle.FileSource import openFileSource
         reloadCache = getattr(self.modelXbrl, "reloadCache", False)
+        if self.modelXbrl.modelManager.formulaOptions.testcaseResultsCaptureWarnings:
+            errorCaptureLevel = logging._checkLevel("WARNING")
+        else:
+            errorCaptureLevel = logging._checkLevel("INCONSISTENCY")# default is INCONSISTENCY
         for rssItem in self.modelXbrl.modelDocument.rssItems:
             if getattr(rssItem, "skipRssItem", False):
                 self.modelXbrl.info("info", _("skipping RSS Item %(accessionNumber)s %(formType)s %(companyName)s %(period)s"),
@@ -152,9 +156,28 @@ class Validate:
                 modelObject=rssItem, accessionNumber=rssItem.accessionNumber, formType=rssItem.formType, companyName=rssItem.companyName, period=rssItem.period)
             modelXbrl = None
             try:
-                modelXbrl = ModelXbrl.load(self.modelXbrl.modelManager,
-                                           openFileSource(rssItem.zippedUrl, self.modelXbrl.modelManager.cntlr, reloadCache=reloadCache),
-                                           _("validating"), rssItem=rssItem)
+                rssItemUrl = rssItem.zippedUrl
+                if self.useFileSource.isArchive and (os.path.isabs(rssItemUrl) or not rssItemUrl.endswith(".zip")):
+                    modelXbrl = ModelXbrl.load(self.modelXbrl.modelManager,
+                                               openFileSource(rssItemUrl, self.modelXbrl.modelManager.cntlr, reloadCache=reloadCache),
+                                               _("validating"), rssItem=rssItem)
+                else: # need own file source, may need instance discovery
+                    filesource = FileSource.openFileSource(rssItemUrl, self.modelXbrl.modelManager.cntlr)
+                    if filesource and not filesource.selection and filesource.isArchive:
+                        try:
+                            from arelle.CntlrCmdLine import filesourceEntrypointFiles
+                            entrypoints = filesourceEntrypointFiles(filesource)
+                            if entrypoints:
+                                # resolve an IXDS in entrypoints
+                                for pluginXbrlMethod in pluginClassMethods("ModelTestcaseVariation.ArchiveIxds"):
+                                    pluginXbrlMethod(self, filesource,entrypoints)
+                                filesource.select(entrypoints[0].get("file", None) )
+                        except Exception as err:
+                            self.modelXbrl.error("exception:" + type(err).__name__,
+                                _("RSS item validation exception: %(error)s, entry URL: %(instance)s"),
+                                modelXbrl=self.modelXbrl, instance=rssItemUrl, error=err)
+                            continue # don't try to load this entry URL
+                    modelXbrl = ModelXbrl.load(self.modelXbrl.modelManager, filesource, _("validating"), rssItem=rssItem, errorCaptureLevel=errorCaptureLevel)
                 for pluginXbrlMethod in pluginClassMethods("RssItem.Xbrl.Loaded"):
                     pluginXbrlMethod(modelXbrl, {}, rssItem)
                 if getattr(rssItem, "doNotProcessRSSitem", False) or modelXbrl.modelDocument is None:
@@ -685,6 +708,9 @@ class Validate:
         if userExpectedErrors := testcaseExpectedErrors.get(variationIdPath):
             if expected is None:
                 expected = []
+            if isinstance(expected, str):
+                assert expected in {"valid", "invalid"}, f"unhandled expected value string '{expected}'"
+                expected = []
             expected.extend(userExpectedErrors)
             if expectedCount is not None:
                 expectedCount += len(userExpectedErrors)
@@ -695,25 +721,17 @@ class Validate:
             elif expectedCount is None:
                 expectedCount = 0
         if expected == "valid":
-            if numErrors == 0:
-                status = "pass"
-            else:
-                status = "fail"
+            status = "pass" if numErrors == 0 else "fail"
         elif expected == "invalid":
-            if numErrors == 0:
-                status = "fail"
-            else:
-                status = "pass"
+            status = "fail" if numErrors == 0 else "pass"
         elif expected in (None, []) and numErrors == 0:
             status = "pass"
         elif isinstance(expected,(QName,str,dict,list)): # string or assertion id counts dict
             status = "fail"
             _passCount = 0
-            if isinstance(expected, list):
-                _expectedList = expected.copy() # need shallow copy
-            else:
-                _expectedList = [expected]
-            if not isinstance(expected, list): expected = [expected]
+            _expectedList = expected.copy() if isinstance(expected, list) else [expected]
+            if not isinstance(expected, list):
+                expected = [expected]
             for testErr in _errors:
                 if isinstance(testErr,str) and testErr.startswith("ESEF."): # compared as list of strings to QName localname
                     testErr = testErr.rpartition(".")[2]
@@ -728,7 +746,7 @@ class Validate:
                             # XDT xml schema tests expected results
                             (_exp.namespaceURI == XbrlConst.xdtSchemaErrorNS and errPrefix == "xmlSchema")):
                             _expMatched = True
-                    elif type(testErr) == type(_exp):
+                    elif type(testErr) is type(_exp):
                         if isinstance(testErr,dict):
                             if len(testErr) == len(_exp) and all(
                                 k in testErr and counts == testErr[k][:len(counts)]
@@ -742,6 +760,7 @@ class Validate:
                              (_exp == "EFM.6.04.03" and (testErr.startswith("xmlSchema:") or testErr.startswith("utr:") or testErr.startswith("xbrl.") or testErr.startswith("xlink:"))) or
                              (_exp == "EFM.6.05.35" and testErr.startswith("utre:")) or
                              (_exp.startswith("EFM.") and testErr.startswith(_exp)) or
+                             (_exp.startswith("EXG.") and testErr.startswith(_exp)) or
                              (_exp == "vere:invalidDTSIdentifier" and testErr.startswith("xbrl"))
                              ))):
                             _expMatched = True
