@@ -25,8 +25,10 @@ from arelle.ModelRelationshipSet import ModelRelationshipSet
 from arelle.ModelValue import QName
 from arelle.ModelValue import qname
 from arelle.ModelXbrl import ModelXbrl
+
 from arelle.PythonUtil import normalizeSpace
 from arelle.PythonUtil import strTruncate
+from arelle.utils.validate.DetectScriptsInXhtml import containsScriptMarkers
 from arelle.UrlUtil import isHttpUrl
 from arelle.ValidateUtr import ValidateUtr
 from arelle.ValidateXbrl import ValidateXbrl
@@ -40,7 +42,7 @@ from arelle.XbrlConst import (
     notAll as hc_notAll,
     parentChild,
     standardLabel,
-    summationItem,
+    summationItems,
     widerNarrower,
     xhtml,
 )
@@ -64,7 +66,7 @@ from ..Const import (
     untransformableTypes,
 )
 from ..Dimensions import checkFilingDimensions
-from ..Util import checkForMultiLangDuplicates, etreeIterWithDepth, getEsefNotesStatementConcepts, hasEventHandlerAttributes, isExtension, getDisclosureSystemYear
+from ..Util import checkForMultiLangDuplicates, etreeIterWithDepth, getEsefNotesStatementConcepts, isExtension, getDisclosureSystemYear
 
 _: TypeGetText  # Handle gettext
 
@@ -249,33 +251,34 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
                         modelXbrl.error("ESEF.RTS.Annex.III.Par.1.invalidInlineXBRL",
                             _("Invalid inline XBRL namespace: %(namespace)s"),
                             modelObject=doc, namespace=doc.ixNS)
-                    # check location in a taxonomy package
-                    # ixds loading for ESEF expects all xhtml instances to be combined into single IXDS regardless of directory in report zip
-                    docDirPath = re.split(r"[/\\]", doc.uri)
-                    reportCorrectlyPlacedInPackage = reportIsInZipFile = False
-                    for i, dir in enumerate(docDirPath):
-                        if dir.lower().endswith(".zip"):
-                            if reportIsInZipFile: # report package was nested in a zip file
-                                ixdsDocDirs.clear() # ignore containing zip
-                            reportIsInZipFile = True
-                            packageName = dir[:-4] # web service posted zips are always named POSTupload.zip instead of the source file name
-                            if len(docDirPath) >= i + 2 and packageName in (docDirPath[i+1],"POSTupload") and docDirPath[i+2] == "reports":
-                                ixdsDocDirs.add("/".join(docDirPath[i+3:-1]))
-                                reportCorrectlyPlacedInPackage = True
-                            else:
-                                ixdsDocDirs.add("/".join(docDirPath[i+1:len(docDirPath)-1])) # needed for error msg on orphaned instance docs
-                    if not reportIsInZipFile:
-                        modelXbrl.error("ESEF.2.6.1.reportIncorrectlyPlacedInPackage",
-                            _("Inline XBRL document MUST be included within an ESEF report package as defined in "
-                               "http://www.xbrl.org/WGN/report-packages/WGN-2018-08-14/report-packages-WGN-2018-08-14"
-                               ".html: %(fileName)s (Document is not in a zip archive)"),
-                            modelObject=doc, fileName=doc.basename)
-                    elif not reportCorrectlyPlacedInPackage:
-                        modelXbrl.error("ESEF.2.6.1.reportIncorrectlyPlacedInPackage",
-                             _("Inline XBRL document MUST be included within an ESEF report package as defined in "
-                               "http://www.xbrl.org/WGN/report-packages/WGN-2018-08-14/report-packages-WGN-2018-08-14"
-                               ".html: %(fileName)s (Document file not in correct place in package)"),
-                            modelObject=doc, fileName=doc.basename)
+                    if esefDisclosureSystemYear <= 2023:
+                        # check location in a taxonomy package
+                        # ixds loading for ESEF expects all xhtml instances to be combined into single IXDS regardless of directory in report zip
+                        docDirPath = re.split(r"[/\\]", doc.uri)
+                        reportCorrectlyPlacedInPackage = reportIsInZipFile = False
+                        for i, dir in enumerate(docDirPath):
+                            if dir.lower().endswith(".zip"):
+                                if reportIsInZipFile: # report package was nested in a zip file
+                                    ixdsDocDirs.clear() # ignore containing zip
+                                reportIsInZipFile = True
+                                packageName = dir[:-4] # web service posted zips are always named POSTupload.zip instead of the source file name
+                                if len(docDirPath) >= i + 2 and packageName in (docDirPath[i+1],"POSTupload") and docDirPath[i+2] == "reports":
+                                    ixdsDocDirs.add("/".join(docDirPath[i+3:-1]))
+                                    reportCorrectlyPlacedInPackage = True
+                                else:
+                                    ixdsDocDirs.add("/".join(docDirPath[i+1:len(docDirPath)-1])) # needed for error msg on orphaned instance docs
+                        if not reportIsInZipFile:
+                            modelXbrl.error("ESEF.2.6.1.reportIncorrectlyPlacedInPackage",
+                                _("Inline XBRL document MUST be included within an ESEF report package as defined in "
+                                "http://www.xbrl.org/WGN/report-packages/WGN-2018-08-14/report-packages-WGN-2018-08-14"
+                                ".html: %(fileName)s (Document is not in a zip archive)"),
+                                modelObject=doc, fileName=doc.basename)
+                        elif not reportCorrectlyPlacedInPackage:
+                            modelXbrl.error("ESEF.2.6.1.reportIncorrectlyPlacedInPackage",
+                                _("Inline XBRL document MUST be included within an ESEF report package as defined in "
+                                "http://www.xbrl.org/WGN/report-packages/WGN-2018-08-14/report-packages-WGN-2018-08-14"
+                                ".html: %(fileName)s (Document file not in correct place in package)"),
+                                modelObject=doc, fileName=doc.basename)
                 else: # non-consolidated
                     if docTypeMatch:
                         if not docTypeMatch.group(1) or docTypeMatch.group(1).lower() == "html":
@@ -326,10 +329,7 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
                                 if xmlLang:
                                     reportXmlLang = xmlLang
                                     firstRootmostXmlLangDepth = depth
-                        if ((eltTag in ("object", "script")) or
-                            (eltTag == "a" and "javascript:" in elt.get("href", "")) or
-                            (eltTag == "img" and "javascript:" in elt.get("src", "")) or
-                            (hasEventHandlerAttributes(elt))):
+                        if containsScriptMarkers(elt):
                             modelXbrl.error(f"{contentOtherThanXHTMLGuidance}.executableCodePresent",
                                 _("Inline XBRL documents MUST NOT contain executable code: %(element)s"),
                                 modelObject=elt, element=eltTag)
@@ -668,7 +668,7 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
                         modelXbrl.error("ESEF.2.2.7.improperApplicationOfEscapeAttribute",
                                           _("Facts with datatype 'dtr-types:textBlockItemType' MUST use the 'escape' attribute set to 'true'. Facts with any other datatype MUST use the 'escape' attribute set to 'false' - fact %(conceptName)s"),
                                           modelObject=f, conceptName=f.concept.qname)
-                    if f.effectiveValue == "0" and f.xValue != 0:
+                    if f.effectiveValue in ["0", "-0"] and f.xValue != 0:
                         modelXbrl.warning("ESEF.2.2.5.roundedValueBelowScaleNotNull",
                                           _("A value that has been rounded and is below the scale should show a value of zero. It has been found to have the value %(value)s - fact %(conceptName)s"),
                                           modelObject=f, value=f.value, conceptName=f.concept.qname)
@@ -851,10 +851,10 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
 
 
         # unused elements in linkbases
-        unreportedLbElts = set()
+        unreportedLbLocs = set()
         for arcroles, error, checkRoots, lbType in (
                     ((parentChild,), "elements{}UsedForTagging{}AppliedInPresentationLinkbase", True, "presentation"),
-                    ((summationItem,), "elements{}UsedForTagging{}AppliedInCalculationLinkbase", False, "calculation"),
+                    ((summationItems,), "elements{}UsedForTagging{}AppliedInCalculationLinkbase", False, "calculation"),
                     ((hc_all, hc_notAll, dimensionDomain,domainMember), "elements{}UsedForTagging{}AppliedInDefinitionLinkbase", False, "definition")):
             if lbType == "calculation":
                 reportedEltsNotInLb = set(c for c in conceptsUsedByFacts if c.isNumeric)
@@ -864,17 +864,17 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
                 for rel in modelXbrl.relationshipSet(arcrole).modelRelationships:
                     fr = rel.fromModelObject
                     to = rel.toModelObject
-                    if arcrole in (parentChild, summationItem):
+                    if arcrole in (parentChild, summationItems):
                         if fr is not None and not fr.isAbstract and fr not in conceptsUsed and isExtension(val, rel):
-                            unreportedLbElts.add(fr)
+                            unreportedLbLocs.add(rel.fromLocator)
                         if to is not None and not to.isAbstract and to not in conceptsUsed and isExtension(val, rel):
-                            unreportedLbElts.add(to)
+                            unreportedLbLocs.add(rel.toLocator)
                     elif arcrole in (hc_all, domainMember, dimensionDomain):
                         # all primary items
                         if fr is not None and not fr.isAbstract and rel.isUsable and fr not in conceptsUsed and isExtension(val, rel) and not fr.type.isDomainItemType:
-                            unreportedLbElts.add(to)
+                            unreportedLbLocs.add(rel.toLocator)
                         if to is not None and not to.isAbstract and rel.isUsable and to not in conceptsUsed and isExtension(val, rel) and not to.type.isDomainItemType:
-                            unreportedLbElts.add(to)
+                            unreportedLbLocs.add(rel.toLocator)
                     reportedEltsNotInLb.discard(fr)
                     reportedEltsNotInLb.discard(to)
 
@@ -889,11 +889,11 @@ def validateXbrlFinally(val: ValidateXbrl, *args: Any, **kwargs: Any) -> None:
             if reportedEltsNotInLb and lbType != "calculation":
                 modelXbrl.warning(f"ESEF.3.4.6.UsableConceptsNotIncludedIn{lbType.title()}Link",
                     _("All concepts used by tagged facts SHOULD be in extension taxonomy %(linkbaseType)s relationships: %(elements)s."),
-                    modelObject=reportedEltsNotInLb, elements=", ".join(sorted((str(c.qname) for c in reportedEltsNotInLb))), linkbaseType=lbType)
-        if unreportedLbElts:
+                    modelObject=reportedEltsNotInLb, elements=", ".join(sorted(str(c.qname) for c in reportedEltsNotInLb)), linkbaseType=lbType)
+        if unreportedLbLocs:
             modelXbrl.warning("ESEF.3.4.6.UsableConceptsNotAppliedByTaggedFacts",
                 _("All usable concepts in extension taxonomy relationships SHOULD be applied by tagged facts: %(elements)s."),
-                modelObject=unreportedLbElts, elements=", ".join(sorted((str(c.qname) for c in unreportedLbElts))))
+                modelObject=unreportedLbLocs, elements=", ".join(sorted(str(loc.dereference().qname) for loc in unreportedLbLocs)))
 
         anchoringToAbstractConcept = set()
         for rel in modelXbrl.relationshipSet(widerNarrower).modelRelationships:
