@@ -25,6 +25,7 @@ from ..DisclosureSystems import (
     DISCLOSURE_SYSTEM_NT16,
     DISCLOSURE_SYSTEM_NT17,
     DISCLOSURE_SYSTEM_NT18,
+    DISCLOSURE_SYSTEM_NT19,
 )
 from ..PluginValidationDataExtension import PluginValidationDataExtension
 
@@ -74,6 +75,7 @@ XHTML_LIST_ITEM_TYPES = {
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_02(
@@ -123,7 +125,8 @@ def rule_fr_nl_1_02(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_03(
@@ -151,6 +154,7 @@ def rule_fr_nl_1_03(
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_04(
@@ -209,7 +213,8 @@ def rule_fr_nl_1_04(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_05(
@@ -237,6 +242,7 @@ def rule_fr_nl_1_05(
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_06(
@@ -270,6 +276,7 @@ def rule_fr_nl_1_06(
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_1_01(
@@ -303,6 +310,7 @@ def rule_fr_nl_1_01(
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_2_03(
@@ -331,7 +339,8 @@ def rule_fr_nl_2_03(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_2_04(
@@ -362,7 +371,8 @@ def rule_fr_nl_2_04(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_2_05(
@@ -394,6 +404,7 @@ def rule_fr_nl_2_05(
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
         DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_2_06(
@@ -440,7 +451,8 @@ def rule_fr_nl_2_06(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_2_07(
@@ -466,7 +478,8 @@ def rule_fr_nl_2_07(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_3_01(
@@ -498,7 +511,8 @@ def rule_fr_nl_3_01(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_3_02(
@@ -524,7 +538,8 @@ def rule_fr_nl_3_02(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_3_03(
@@ -551,7 +566,8 @@ def rule_fr_nl_3_03(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_3_04(
@@ -580,7 +596,8 @@ def rule_fr_nl_3_04(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_4_01(
@@ -609,7 +626,8 @@ def rule_fr_nl_4_01(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_4_02(
@@ -637,7 +655,8 @@ def rule_fr_nl_4_02(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_5_01(
@@ -670,7 +689,8 @@ def rule_fr_nl_5_01(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_5_03(
@@ -696,7 +716,8 @@ def rule_fr_nl_5_03(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_5_06(
@@ -722,7 +743,8 @@ def rule_fr_nl_5_06(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_5_11(
@@ -823,7 +845,8 @@ def rule_fr_nl_5_11(
     disclosureSystems=[
         DISCLOSURE_SYSTEM_NT16,
         DISCLOSURE_SYSTEM_NT17,
-        DISCLOSURE_SYSTEM_NT18
+        DISCLOSURE_SYSTEM_NT18,
+        DISCLOSURE_SYSTEM_NT19,
     ],
 )
 def rule_fr_nl_6_01(
